pub enum Query {
Show 35 variants
GetProfile,
IsNetworkingActive,
GetConnectionIdentity,
GetExternalAddress,
GetEntity {
entity_id: String,
},
ListEntities,
ListEntitiesByType {
entity_type: EntityType,
},
ListChildEntities {
org_id: String,
},
ListMembers {
entity_type: EntityType,
entity_id: String,
},
GetMemberRole {
entity_type: EntityType,
entity_id: String,
member_id: String,
},
GetPermissionOverrides {
entity_type: EntityType,
entity_id: String,
member_id: String,
},
GetMessage {
entity_id: String,
message_id: String,
},
GetEntityMessages {
entity_id: String,
},
GetThreadMessages {
entity_id: String,
parent_message_id: String,
},
GetDirectMessages {
other_peer_id: String,
},
GetEntitySyncState {
entity_id: String,
entity_type: EntityType,
},
GetInvite {
invite_id: String,
},
ListPendingInvites,
ListSentInvites,
ReadFile {
entity_id: String,
disk_type: DiskTypeArg,
path: String,
},
ListFiles {
entity_id: String,
disk_type: DiskTypeArg,
path: String,
},
GetDiskStats {
entity_id: String,
disk_type: DiskTypeArg,
},
GetKanbanBoard {
board_id: String,
},
ListKanbanBoards {
entity_id: String,
},
GetKanbanCard {
board_id: String,
card_id: String,
},
ListKanbanCards {
board_id: String,
column_id: Option<String>,
state: Option<String>,
assignee_id: Option<String>,
tag_id: Option<String>,
},
GetPresence {
peer_id: String,
},
ListOnlinePeers,
ListActiveCalls,
GetCallParticipants {
call_id: String,
},
GetContact {
contact_id: String,
},
ListContacts,
ListFavouriteContacts,
SearchContacts {
query: String,
},
GetWebsite {
entity_id: String,
},
}Expand description
Queries represent all possible reads from the application state.
All state reads should go through queries to enable:
- Consistent responses across adapters
- Access control enforcement
- Caching strategies
- MCP server exposure
Variants
GetProfile
Get the current user profile
IsNetworkingActive
Check if networking is active
GetConnectionIdentity
Get connection identity
GetExternalAddress
Get external address
GetEntity
Get an entity by ID
ListEntities
List all entities
ListEntitiesByType
List entities by type
Fields
entity_type: EntityTypeListChildEntities
List child entities of an organization
ListMembers
List members of an entity
GetMemberRole
Get a member’s role
GetPermissionOverrides
Get permission overrides for a member
GetMessage
Get a single message by ID (includes reactions)
GetEntityMessages
Get messages for an entity
GetThreadMessages
Get thread messages (replies to a parent message)
GetDirectMessages
Get direct messages with a peer
GetEntitySyncState
Get entity sync state
GetInvite
Get an invite by ID
ListPendingInvites
List pending invites for current user
ListSentInvites
List invites sent by current user
ReadFile
Read a file from an entity’s virtual disk
ListFiles
List files in a directory
GetDiskStats
Get disk statistics
GetKanbanBoard
Get a Kanban board
ListKanbanBoards
List Kanban boards for an entity
GetKanbanCard
Get a Kanban card
ListKanbanCards
List Kanban cards in a board with optional filters
Fields
GetPresence
Get presence info for a peer
ListOnlinePeers
List online peers
ListActiveCalls
List active calls
GetCallParticipants
Get call participants
GetContact
Get a contact by ID or four-words
ListContacts
List all contacts
ListFavouriteContacts
List favourite contacts only
SearchContacts
Search contacts by display name
GetWebsite
Get website information for an entity